#########################################################

# Warming SSTs are linked to lower shorebird migratory fuel loads

#  Lagassé, BJ, and GA Breed

#########################################################


####
##
# Clear environment, load packages, set working directory
rm(list=ls())
z <- c("lme4","MuMIn","ggplot2","dplyr","rnaturalearth","sf",
       "raster","gridExtra","climwin","FlyingR","afpt","cowplot",
       "geosphere","RNCEP")
lapply(z, library, character.only=TRUE)
setwd("~/Desktop/Figshare/Data_files")


### Load capture data
cap <- read.csv("Angyo_Dunlin_morphological_measurements.csv")
cap$Year <- as.factor(cap$Year)
cap$Body_Mass <- as.numeric(cap$Body_Mass)
cap$Age <- as.factor(cap$Age) # 1 = ADU, 2 = JUV
cap <- cap[cap$Subspecies!="arcticola",] # remove known male arcticola (74/4254 = 0.017)

# 1-21 Aug captures
table(cap[cap$Julian_Date < 234,]$Age, cap[cap$Julian_Date < 234,]$Year)
# 22 Aug - 22 Sep captures
table(cap[cap$Julian_Date > 233 & cap$Julian_Date < 266,]$Age, cap[cap$Julian_Date > 233 & cap$Julian_Date < 266,]$Year)
# 4 Oct 1980 captures
table(cap[cap$Julian_Date > 265,]$Age, cap[cap$Julian_Date > 265,]$Year)


####
##
# Structural lean body mass analyses
#########################################################
####
##
#

### Capture records of pre-staging Dunlin (1-21 Aug)
df.PRE <- cap[cap$Julian_Date < 234,]

### Model comparison
PRE.m0 <- lmer(Body_Mass ~ 1 + (1|Year),
               data=df.PRE, REML=FALSE)

PRE.m1 <- lmer(Body_Mass ~ Exposed_Culmen + (1|Year),
             data=df.PRE, REML=FALSE)

PRE.m2 <- lmer(Body_Mass ~ Exposed_Culmen + Age + (1|Year),
             data=df.PRE, REML=FALSE)

PRE.m3 <- lmer(Body_Mass ~ Exposed_Culmen * Age + (1|Year), 
             data=df.PRE, REML=FALSE)

model.sel(PRE.m0,PRE.m1,PRE.m2,PRE.m3)

### coefficient estimates for top model
PRE.m3 <- lmer(Body_Mass ~ Exposed_Culmen * Age +
               (1|df.PRE$Year), data=df.PRE, REML=TRUE)

### Calculate residual masses using age-specific regression equations
df.ADU <- df.PRE[df.PRE$Age==1,]
df.JUV <- df.PRE[df.PRE$Age==2,]

for (i in 1:dim(df.ADU)[1]){
  df.ADU$Structural_LBM[i] <- summary(PRE.m3)[["coefficients"]][1,1]+
    (summary(PRE.m3)[["coefficients"]][2,1]*df.ADU$Exposed_Culmen[i])
  df.ADU$Residual_Mass[i] <- df.ADU$Body_Mass[i]-df.ADU$Structural_LBM[i]
  df.ADU$Residual_Percent_LBM[i] <- (df.ADU$Residual_Mass[i]/df.ADU$Structural_LBM[i])*100
}  

for (i in 1:dim(df.JUV)[1]){
  df.JUV$Structural_LBM[i] <- (summary(PRE.m3)[["coefficients"]][1,1]+summary(PRE.m3)[["coefficients"]][3,1])+
    ((summary(PRE.m3)[["coefficients"]][2,1]+summary(PRE.m3)[["coefficients"]][4,1])*df.JUV$Exposed_Culmen[i])
  df.JUV$Residual_Mass[i] <- df.JUV$Body_Mass[i]-df.JUV$Structural_LBM[i]
  df.JUV$Residual_Percent_LBM[i] <- (df.JUV$Residual_Mass[i]/df.JUV$Structural_LBM[i])*100
}

df.PRE <- rbind(df.ADU,df.JUV)



# Residuals by age
ggplot(df.PRE, aes(x=Residual_Percent_LBM)) + 
  geom_density() + facet_grid(Age ~ .)

# Residuals by age and year
df <- group_by(df.PRE, Age, Year) %>% 
  summarise(
    mean = mean(Residual_Percent_LBM),
    n = length(Residual_Percent_LBM),
    se = sd(Residual_Percent_LBM)/sqrt(length(Residual_Percent_LBM)))

ggplot(df, aes(x=Year, y=mean, fill=Age)) +
  geom_hline(yintercept=0, linetype="dashed", color = "grey55") + 
  geom_errorbar(aes(ymin=mean-(se*1.96), ymax=mean+(se*1.96)), width = 0.4, position=position_dodge(width=0.75)) +
  geom_point(shape=21, stroke=0.5, size = 2, position=position_dodge(width=0.75)) +
  scale_y_continuous(limits=c(-5.5,5.5), breaks=c(-5,-2.5,0,2.5,5), labels=c("-5","-2.5","0","2.5","5")) +
  scale_fill_manual(labels=c("ADU","JUV"),values=c("#4477aa","#ee6677")) +
  facet_grid(Age ~ .)
  
  

####
##
# 

### Capture records of fall staging Dunlin (22 Aug - 22 Sep)
df.STAGE <- cap[cap$Julian_Date > 233 & cap$Julian_Date < 266,]

### Calculate residual masses using age-specific regression equations
df.ADU <- df.STAGE[df.STAGE$Age==1,]
df.JUV <- df.STAGE[df.STAGE$Age==2,]

for (i in 1:dim(df.ADU)[1]){
  df.ADU$Structural_LBM[i] <- summary(PRE.m3)[["coefficients"]][1,1]+
    (summary(PRE.m3)[["coefficients"]][2,1]*df.ADU$Exposed_Culmen[i])
  df.ADU$Residual_Mass[i] <- df.ADU$Body_Mass[i]-df.ADU$Structural_LBM[i]
  df.ADU$Residual_Percent_LBM[i] <- (df.ADU$Residual_Mass[i]/df.ADU$Structural_LBM[i])*100
}  

for (i in 1:dim(df.JUV)[1]){
  df.JUV$Structural_LBM[i] <- (summary(PRE.m3)[["coefficients"]][1,1]+summary(PRE.m3)[["coefficients"]][3,1])+
    ((summary(PRE.m3)[["coefficients"]][2,1]+summary(PRE.m3)[["coefficients"]][4,1])*df.JUV$Exposed_Culmen[i])
  df.JUV$Residual_Mass[i] <- df.JUV$Body_Mass[i]-df.JUV$Structural_LBM[i]
  df.JUV$Residual_Percent_LBM[i] <- (df.JUV$Residual_Mass[i]/df.JUV$Structural_LBM[i])*100
}

df.STAGE <- rbind(df.ADU,df.JUV)

#########################################################



####
##
# Residual mass analyses
#########################################################
####
##
#

# 22 - 29 Aug captures
table(df.STAGE[df.STAGE$Julian_Date > 233 & df.STAGE$Julian_Date < 242,]$Age, 
      df.STAGE[df.STAGE$Julian_Date > 233 & df.STAGE$Julian_Date < 242,]$Year)
# 30 Aug - 6 Sep captures
table(df.STAGE[df.STAGE$Julian_Date > 241 & df.STAGE$Julian_Date < 250,]$Age, 
      df.STAGE[df.STAGE$Julian_Date > 241 & df.STAGE$Julian_Date < 250,]$Year)
# 7 - 14 Sep captures
table(df.STAGE[df.STAGE$Julian_Date > 249 & df.STAGE$Julian_Date < 258,]$Age, 
      df.STAGE[df.STAGE$Julian_Date > 249 & df.STAGE$Julian_Date < 258,]$Year)
# 15 - 22 Sep captures
table(df.STAGE[df.STAGE$Julian_Date > 257 & df.STAGE$Julian_Date < 266,]$Age, 
      df.STAGE[df.STAGE$Julian_Date > 257 & df.STAGE$Julian_Date < 266,]$Year)


### Modeling Residual_Percent_LBM by Date

## Regression data frame
df.STAGE.glm <- df.STAGE[df.STAGE$Year == 1978 | df.STAGE$Year == 1979 |
                           df.STAGE$Year == 1980 | df.STAGE$Year == 2008 |
                           df.STAGE$Year == 2009 | df.STAGE$Year == 2010,]
df.STAGE.glm$Date <- df.STAGE.glm$Julian_Date-233 #Day 1 = 22 Aug
df.STAGE.glm$Pos_Residual_Percent_LBM <- df.STAGE.glm$Residual_Percent_LBM+24 #Positive Residual_Percent_LBM for log link

## Sub-sample regression data frame in order that juveniles and adults have equal representation across years and sample periods
# assign 8-day sample period
for (i in 1:dim(df.STAGE.glm)[1]){
  if (df.STAGE.glm$Date[i] < 9)
    {df.STAGE.glm$Cap_Prd[i] <- 1}
  if (df.STAGE.glm$Date[i] > 8 & df.STAGE.glm$Date[i] < 17)
    {df.STAGE.glm$Cap_Prd[i] <- 2}
  if (df.STAGE.glm$Date[i] > 16 & df.STAGE.glm$Date[i] < 25)
    {df.STAGE.glm$Cap_Prd[i] <- 3}
  if (df.STAGE.glm$Date[i] > 24)
    {df.STAGE.glm$Cap_Prd[i] <- 4}
}
# sub-sample
prd <- unique(df.STAGE.glm$Cap_Prd)
yr <- unique(df.STAGE.glm$Year)
df.STAGE.glm <- df.STAGE.glm[sample(1:dim(df.STAGE.glm)[1]),] # shuffle rows of data frame
df.STAGE.glm.eqln <- df.STAGE.glm[1,]
for (i in 1:length(prd)){
  df.prd <- df.STAGE.glm[df.STAGE.glm$Cap_Prd == i,]
  for (j in 1:length(yr)){
    df.prd.adu <- df.prd[df.prd$Age==1 & df.prd$Year==yr[j],]
    df.prd.juv <- df.prd[df.prd$Age==2 & df.prd$Year==yr[j],]
    cnt <- c(dim(df.prd.adu)[1], dim(df.prd.juv)[1])
    df <- rbind(df.prd.adu[1:min(cnt),], df.prd.juv[1:min(cnt),])
    df.STAGE.glm.eqln <- rbind(df.STAGE.glm.eqln, df)
  }
}
df.STAGE.glm.eqln <- df.STAGE.glm.eqln[-1,] # remove initial entry
df.STAGE.glm.eqln <- df.STAGE.glm.eqln[is.na(df.STAGE.glm.eqln$Year)==F,] # remove NAs
df.STAGE.glm.eqln <- df.STAGE.glm.eqln[-1143,] # remove 1980 Cap_Prd 3
df.STAGE.glm.eqln <- df.STAGE.glm.eqln[-1181,] # remove 1980 Cap_Prd 4
table(df.STAGE.glm.eqln$Age, df.STAGE.glm.eqln$Year) # confirm correct n
table(df.STAGE.glm.eqln$Age, df.STAGE.glm.eqln$Cap_Prd) # confirm correct n
#save(df.STAGE.glm.eqln,file="STAGE.glm.eqln.rda")
load("STAGE.glm.eqln.rda") # load the data set presented in the manuscript

m.ADU <- glmer(Pos_Residual_Percent_LBM ~ Date + (1|Year), 
             data=df.STAGE.glm.eqln[df.STAGE.glm.eqln$Age==1,], family=Gamma(link="log"))

exp(summary(m.ADU)$coefficients[1,1]+(summary(m.ADU)$coefficients[2,1]*1))-24 # 22 Aug Res_Per_LBM
exp((summary(m.ADU)$coefficients[1,1]-(summary(m.ADU)$coefficients[1,2]*1.96))+
      ((summary(m.ADU)$coefficients[2,1]-(summary(m.ADU)$coefficients[2,2]*1.96))*1))-24 # 22 Aug lci
exp((summary(m.ADU)$coefficients[1,1]+(summary(m.ADU)$coefficients[1,2]*1.96))+
      ((summary(m.ADU)$coefficients[2,1]+(summary(m.ADU)$coefficients[2,2]*1.96))*1))-24 # 22 Aug uci
summary(m.ADU)$coefficients[2,1] #date
summary(m.ADU)$coefficients[2,1]-(summary(m.ADU)$coefficients[2,2]*1.96) #date lci
summary(m.ADU)$coefficients[2,1]+(summary(m.ADU)$coefficients[2,2]*1.96) #date uci


m.JUV <- glmer(Pos_Residual_Percent_LBM ~ Date + (1|Year), 
             data=df.STAGE.glm.eqln[df.STAGE.glm.eqln$Age==2,], family=Gamma(link="log"))

exp(summary(m.JUV)$coefficients[1,1]+(summary(m.JUV)$coefficients[2,1]*1))-24 # 22 Aug
exp((summary(m.JUV)$coefficients[1,1]-(summary(m.JUV)$coefficients[1,2]*1.96))+
      ((summary(m.JUV)$coefficients[2,1]-(summary(m.JUV)$coefficients[2,2]*1.96))*1))-24 # 22 Aug lci
exp((summary(m.JUV)$coefficients[1,1]+(summary(m.JUV)$coefficients[1,2]*1.96))+
      ((summary(m.JUV)$coefficients[2,1]+(summary(m.JUV)$coefficients[2,2]*1.96))*1))-24 # 22 Aug uci
summary(m.JUV)$coefficients[2,1] #date
summary(m.JUV)$coefficients[2,1]-(summary(m.JUV)$coefficients[2,2]*1.96) #date lci
summary(m.JUV)$coefficients[2,1]+(summary(m.JUV)$coefficients[2,2]*1.96) #date uci


### Calculating pre-migratory body conditions (i.e., relative mass after correcting for structural size and capture date)

#ADU
#pre-migratory body condition results column
df.ADU$Body_Condition <- NA
#list of capture dates
ADU.cap.dates <- unique(df.ADU$Julian_Date-233)
#empty results data frame
df.ADU.Body_Condition <- df.ADU[1,]
#loop through capture dates
for (i in 1:length(ADU.cap.dates)){
  #subset capture records and calculate the expected residual mass value
  df.obs <- df.ADU[df.ADU$Julian_Date-233==ADU.cap.dates[i],]
  exp.Residual_Percent_LBM <- exp((summary(m.ADU)$coefficients[1,1])+
                       (summary(m.ADU)$coefficients[2,1]*ADU.cap.dates[i]))-24
  #loop through observed values
  for (j in 1:dim(df.obs)[1]){
    df.obs$Body_Condition[j] <- df.obs$Residual_Percent_LBM[j]-exp.Residual_Percent_LBM
  }
  df.ADU.Body_Condition <- rbind(df.ADU.Body_Condition,df.obs)
}
#final results data frame
df.ADU <- df.ADU.Body_Condition[-1,]


#JUV
#pre-migratory body condition results column
df.JUV$Body_Condition <- NA
#list of capture dates
JUV.cap.dates <- unique(df.JUV$Julian_Date-233)
#empty results data frame
df.JUV.Body_Condition <- df.JUV[1,]
#loop through capture dates
for (i in 1:length(JUV.cap.dates)){
  #subset capture records and calculate the expected residual mass value
  df.obs <- df.JUV[df.JUV$Julian_Date-233==JUV.cap.dates[i],]
  exp.Residual_Percent_LBM <- exp((summary(m.JUV)$coefficients[1,1])+
                       (summary(m.JUV)$coefficients[2,1]*JUV.cap.dates[i]))-24
  #loop through observed values
  for (j in 1:dim(df.obs)[1]){
    df.obs$Body_Condition[j] <- df.obs$Residual_Percent_LBM[j]-exp.Residual_Percent_LBM
  }
  df.JUV.Body_Condition <- rbind(df.JUV.Body_Condition,df.obs)
}
#final results data frame
df.JUV <- df.JUV.Body_Condition[-1,]


#
df.RESID <- rbind(df.ADU, df.JUV)

#########################################################



####
##
# Figure 1
#########################################################
####
##
#

# data frames
df.glm <- data.frame(glm.date = 1:32,
                     adu.lci = exp((summary(m.ADU)$coefficients[1,1]-(summary(m.ADU)$coefficients[1,2]*1.96))+
                                     ((summary(m.ADU)$coefficients[2,1]-(summary(m.ADU)$coefficients[2,2]*1.96))*1:32))-24,
                     adu = exp(summary(m.ADU)$coefficients[1,1]+(summary(m.ADU)$coefficients[2,1]*1:32))-24,
                     adu.uci = exp((summary(m.ADU)$coefficients[1,1]+(summary(m.ADU)$coefficients[1,2]*1.96))+
                                     ((summary(m.ADU)$coefficients[2,1]+(summary(m.ADU)$coefficients[2,2]*1.96))*1:32))-24,
                     juv.lci = exp((summary(m.JUV)$coefficients[1,1]-(summary(m.JUV)$coefficients[1,2]*1.96))+
                                     ((summary(m.JUV)$coefficients[2,1]-(summary(m.JUV)$coefficients[2,2]*1.96))*1:32))-24,
                     juv = exp(summary(m.JUV)$coefficients[1,1]+(summary(m.JUV)$coefficients[2,1]*1:32))-24,
                     juv.uci = exp((summary(m.JUV)$coefficients[1,1]+(summary(m.JUV)$coefficients[1,2]*1.96))+
                                     ((summary(m.JUV)$coefficients[2,1]+(summary(m.JUV)$coefficients[2,2]*1.96))*1:32))-24)

df.glm.ci.poly <- data.frame(Date = c(1:32,32:1,1),
                             adu.ci = c(df.glm$adu.lci[1:32],df.glm$adu.uci[32:1],df.glm$adu.lci[1]),
                             juv.ci = c(df.glm$juv.lci[1:32],df.glm$juv.uci[32:1],df.glm$juv.lci[1]))
  

# tile a
base.lnd<-ne_countries(scale="medium", returnclass="sf")
base.lnd<-st_transform(base.lnd, crs = st_crs("+proj=laea +lat_0=50 +lon_0=-120 +x_0=0 +y_0=0 +ellps=WGS84 +units=m +no_defs"))

#locations to transform
df.loc <- data.frame( lat = c(61.25,60.41,58.50,57.56,46.97),
                      lon = c(-165.65,-165.47,-162.13,-157.62,-124.07),
                      grp = rep("grp",5))

a<-cbind(df.loc$lon,df.loc$lat)
b<-pointDistance(a,a, lonlat=TRUE, allpairs=TRUE)
(b[2,1]+b[3,2]+b[4,3]+b[5,4])/1000 # minimum migration distance = 3,205 km

#project points
points <- st_as_sf(df.loc, coords = c("lon", "lat"), crs = 4326)
points <- st_transform(points, crs = "+proj=laea +lat_0=50 +lon_0=-120 +x_0=0 +y_0=0 +ellps=WGS84 +units=m +no_defs")
for (i in 1:dim(df.loc)[1]){
  df.loc$lon[i]<-points$geometry[[i]][1]
  df.loc$lat[i]<-points$geometry[[i]][2]
}

a <- ggplot()+
  geom_sf(data = base.lnd)+
  coord_sf(xlim=c(-2740000,0000), ylim=c(-650000,2800000),
           expand=FALSE)+
  geom_line(data=df.loc[1:2,], aes(x=lon,y=lat), linetype = 3, lineend="round", linewidth=1.25)+
  geom_line(data=df.loc[2:5,], aes(x=lon,y=lat), linetype = 3, lineend="round", linewidth=1.25)+
  geom_line(data=df.loc[df.loc$sgmnt=="AB" | df.loc$sgmnt=="C",],
            aes(x=lon,y=lat,group=grp), linetype = 3, linewidth=1.25)+
  geom_point(data=df.loc[1,],
             aes(x=lon,y=lat,group=grp), shape=25, fill="ivory", color="black", stroke=1.5, size=4)+
  geom_point(data=df.loc[5,],
             aes(x=lon,y=lat,group=grp), shape=24, fill="ivory", color="black", stroke=1.5, size=4)+
  annotate("rect", xmin =-2680000, xmax = -1450000, ymin = -600000, ymax = 50000,alpha = 1, color = "black", fill="white") +
  geom_point(aes(x=-2530000,y=-500000), shape=24, fill="ivory", color="black", stroke=1.5, size=4)+
  annotate("text", x = -1950000, y = -480000, label = "Grays Harbor", colour = "black", size = 4) +
  geom_line(aes(x=c(-2650000,-2300000),y=c(-280000,-280000)), linetype = 3, lineend="round", linewidth=1.25)+
  annotate("text", x = -1920000, y = -280000, label = "Migration route", colour = "black", size = 4) +
  geom_point(aes(x=-2530000,y=-60000), shape=25, fill="ivory", color="black", stroke=1.5, size=4)+
  annotate("text", x = -1925000, y = -60000, label = "Angyoyaravak Bay", colour = "black", size = 4) +
  scale_x_continuous(breaks = c(180,-170,-160,-150,-140,-130))+
  scale_y_continuous(breaks = c(40,45,50,55,60,65,70,75))+
  labs(title = expression(paste("(",italic("a"),")")))+
  theme_bw()+
  theme(axis.title.x=element_blank()) + theme(axis.title.y=element_blank())


# tile b
b <- ggplot(df.STAGE.glm.eqln[df.STAGE.glm.eqln$Age==2,], aes(x=Julian_Date-233,y=Residual_Percent_LBM))+
  geom_polygon(data=df.glm.ci.poly,aes(x=Date,y=juv.ci),fill="grey55", alpha=0.6)+
  geom_point(alpha=0.075)+
  geom_path(data=df.glm,aes(x=glm.date, y=juv),color="#ee6677", linewidth=1)+
  scale_x_continuous(limits=c(1,32), breaks=c(3,16,29),
                     labels=c("24 Aug","6 Sep","19 Sep"))+
  scale_y_continuous(limits=c(-24,88))+
  annotate("rect", xmin = 2, xmax = 10, ymin = 77, ymax = 87,alpha = 1, fill="white")+
  annotate("text", x = 6, y = 81.25, label = "JUV", colour = "black", size = 4)+
  labs(x = "", 
       y = "Fuel load (%lbm)",
       title = expression(paste("(",italic("b"),")")))+
  theme_bw() +
  theme(plot.margin=unit(c(5.5,5.5,-5.5,5.5), 'pt'))


# tile c
c <- ggplot(df.STAGE.glm.eqln[df.STAGE.glm.eqln$Age==1,], aes(x=Julian_Date-233,y=Residual_Percent_LBM))+
  geom_polygon(data=df.glm.ci.poly,aes(x=Date,y=adu.ci),fill="grey55", alpha=0.6)+
  geom_point(alpha=0.075)+
  geom_path(data=df.glm,aes(x=glm.date, y=adu),color="#4477aa", size=1)+
  scale_x_continuous(limits=c(1,32), breaks=c(3,16,29),
                     labels=c("24 Aug","6 Sep","19 Sep"))+
  scale_y_continuous(limits=c(-24,88))+
  annotate("rect", xmin =2, xmax = 10, ymin = 77, ymax = 87,alpha = 1, fill="white")+
  annotate("text", x = 6, y = 81.25, label = "ADU", colour = "black", size = 4)+
  labs(x = "", 
       y = "Fuel load (%lbm)",
       title = expression(paste("(",italic("c"),")")))+
  theme_bw() +
  theme(plot.margin=unit(c(5.5,5.5,-5.5,5.5), 'pt'))


# tile d
df<-data.frame(Age = as.factor(c("A1","A2")),
                   Mean = c(0.0147,0.0220),
                   LCI = c(0.0112,0.0177),
                   UCI = c(0.0182,0.0263))

d <- ggplot(df, aes(x=Age,y=Mean, color=Age))+
  geom_pointrange(aes(ymin=LCI, ymax=UCI),show.legend = FALSE,size=0.5)+
  scale_color_manual(values=c("#ee6677", "#4477aa"))+
  scale_y_continuous(breaks=c(0.012,0.018,0.024), labels=c("0.012","0.018","0.024"))+
  scale_x_discrete(breaks=c("A1", "A2"), labels=c("JUV","ADU"))+
  labs(y = expression(paste(beta[Date])),
       x = element_blank(),
       title = expression(paste("(",italic("d"),")")))+
  theme_bw() +
  theme(plot.margin=unit(c(5.5,5.5,5.5,5.5), 'pt'))


grid.arrange(a, b, c, d, ncol = 3, 
             layout_matrix = cbind(c(1,1,1), c(1,1,1), c(1,1,1), c(1,1,1), c(1,1,1), 
                                   c(2,3,4), c(2,3,4)))
# 7 x 6.3 - landscape

#########################################################



####
##
# Figure 2
#########################################################

df.PMBC <- data.frame( Year = as.factor(c(as.character(df.RESID$Year),rep("2003",2),rep("2007",2))),
                       Age = as.numeric(c(df.RESID$Age,rep(c("1","2"),2))),
                       Body_Condition = as.numeric(c(df.RESID$Body_Condition,rep("NA",4))))
for (i in 1:dim(df.PMBC)[1]){
  if (df.PMBC$Age[i] > 1){
    df.PMBC$Age[i] <- "aJUV"}
  if (df.PMBC$Age[i] < 2){
    df.PMBC$Age[i] <- "bADU"}}
df.PMBC$Age <- as.factor(df.PMBC$Age)

df <- group_by(df.PMBC, Age, Year) %>% 
  summarise(
    mean = mean(Body_Condition),
    n = length(Body_Condition),
    se = sd(Body_Condition)/sqrt(length(Body_Condition)))
df[16:18,3:5] <- NA



ggplot(df, aes(x=Year, y=mean, fill=Age)) +
  geom_hline(yintercept=0, linetype="dashed", color = "grey55") + 
  geom_errorbar(aes(ymin=mean-(se*1.96), ymax=mean+(se*1.96)), width = 0.4, position=position_dodge(width=0.75)) +
  geom_point(shape=21, stroke=0.5, size = 2, position=position_dodge(width=0.75)) +
  scale_x_discrete(breaks=c(1978,1979,1980,2003,2004,2005,2006,2007,2008,2009,2010),
                   labels=c("'78","'79","'80","","'04","'05","'06","","'08","'09","'10"))+
  scale_y_continuous(limits=c(-5.5,5.5), breaks=c(-5,-2.5,0,2.5,5), labels=c("-5","-2.5","0","2.5","5"))+
  scale_fill_manual(labels=c("JUV", "ADU"),values=c("#ee6677", "#4477aa"))+
  labs(x = "Year", 
       y = "Body condition (%lbm)",
       title = expression(paste("")),
       fill = NULL)+
  theme_bw() +
  theme(plot.margin=unit(c(18,5.5,5.5,5.5), 'pt'),
        legend.direction="horizontal",legend.position=c(0.2,1.085))


#ggsave(filename = "Fig2.jpeg", width=3.5, height=3.18,
 #      units="in", dpi=300)

#########################################################



####
##
# Climate analyses
#########################################################
####
##
#

### Load weather data
df.ENV <- read.csv("cYKD_daily_weather.csv")


### Sliding window analyses (cdate and bdate formats must = dd/mm/yyyy)
climwin <- slidingwin( baseline = lmer(Body_Condition ~ 1 + (1|Year), data=df.JUV, REML=FALSE),
                       xvar = list(lag.sst=df.ENV$Lag_mean_SST,
                                   precip=df.ENV$Tot_precip,
                                   t2m=df.ENV$Mean_t2m,
                                   sst=df.ENV$Mean_SST),
                       type = "absolute",
                       range = c(16, 0),
                       stat = c("mean"),
                       func = c("lin", "quad"),
                       refday = c(21, 8),
                       cinterval = "week",
                       cdate = df.ENV$Date_ddmmyy, bdate = df.JUV$Date_ddmmyy); climwin$combos

# randomization function — assess chance that best models represent false positives  
randwin.quad <- randwin( baseline = lmer(Body_Condition ~ 1 + (1|Year), data=df.JUV, REML=FALSE),
                         repeats = 10,
                         window = "sliding",
                         xvar =list(lag.sst=df.ENV$Lag_mean_SST,
                                    precip=df.ENV$Tot_precip,
                                    t2m=df.ENV$Mean_t2m),
                         type = "absolute",
                         range = c(16, 0),
                         stat = c("mean"),
                         func = c("quad"),
                         refday = c(21, 8),
                         cinterval = "week",
                         cdate = df.ENV$Date_ddmmyy, bdate = df.JUV$Date_ddmmyy)

randwin.lin <- randwin( baseline = lmer(Body_Condition ~ 1 + (1|Year), data=df.JUV, REML=FALSE),
                        repeats = 10,
                        window = "sliding",
                        xvar =list(sst=df.ENV$Mean_SST),
                        type = "absolute",
                        range = c(16, 0),
                        stat = c("mean"),
                        func = c("lin"),
                        refday = c(21, 8),
                        cinterval = "week",
                        cdate = df.ENV$Date_ddmmyy, bdate = df.JUV$Date_ddmmyy)


# lag.sst
pvalue(dataset = climwin[[5]]$Dataset, datasetrand = randwin.quad[[1]],
       metric = "C", sample.size = 9) # 0.0455
plotdelta(dataset = climwin[[5]]$Dataset, arrow=F) # distribution of model support across model set

# precip
pvalue(dataset = climwin[[6]]$Dataset, datasetrand = randwin.quad[[2]],
       metric = "C", sample.size = 9) # 0.0441
plotdelta(dataset = climwin[[6]]$Dataset, arrow=F) # distribution of model support across model set

# t2m
pvalue(dataset = climwin[[7]]$Dataset, datasetrand = randwin.quad[[3]],
       metric = "C", sample.size = 9) # 0.2995

# sst
pvalue(dataset = climwin[[4]]$Dataset, datasetrand = randwin.lin[[1]],
       metric = "C", sample.size = 9) # 0.4131


### Correlation between lag.sst[[5]] and precip[[6]]
cor(climwin[[5]]$BestModelData[,3], climwin[[6]]$BestModelData[,3],
    method = "pearson") # (r = -0.87)


### Comparing candidate climate variables

# candidate climate variables data frame
df.CLMT <- cbind(df.JUV,
                 climwin[[5]]$BestModelData[,3:4],
                 climwin[[6]]$BestModelData[,3:4])
colnames(df.CLMT)[18:21] <- c("Mean_Lag_SST", "Mean_Lag_SST_sq",
                              "Mean_Precip", "Mean_Precip_sq") 

# candidate models
CLMT.m0 <- lmer(Body_Condition ~ 1 + (1|Year), data=df.CLMT, REML=FALSE)

CLMT.m1 <- lmer(Body_Condition ~ Mean_Lag_SST + Mean_Lag_SST_sq + (1|Year), data=df.CLMT, REML=FALSE)

CLMT.m2 <- lmer(Body_Condition ~ Mean_Precip + Mean_Precip_sq + (1|Year), data=df.CLMT, REML=FALSE)

CLMT.m3 <- lmer(Body_Condition ~ (Mean_Precip + Mean_Precip_sq) * (Mean_Lag_SST + Mean_Lag_SST_sq) + (1|Year), data=df.CLMT, REML=FALSE)

model.sel(CLMT.m0, CLMT.m1, CLMT.m2, CLMT.m3)

#########################################################



####
##
# Wind assistance
#########################################################
####
##
#

# average bearing
a<-cbind(c(-166.75,-124.07), # lon
         c(58.345,46.97)) # lat
mean(c(bearing(a[1,],a[2,]),finalBearing(a[1,],a[2,])))


# average daily wind assistance
df.day.wind <- read.csv("Southbound_wind_conditions.csv")

df.airspeed <- NCEP.Airspeed(u=df.day.wind$avg.u, v=df.day.wind$avg.v,
                             direction = 112.5, airspeed = 16.1)

df.day.wind$avg_air_speed <- 16.1
df.day.wind$preferred_direction <- 112.5
df.day.wind$avg_wind_assist <- df.airspeed$fa
df.day.wind$avg_ground_speed <- df.airspeed$groundspeed

#write.csv(df.day.wind,"Southbound_wind_conditions.csv")

quantile(df.day.wind$avg_wind_assist, 0.80)

#########################################################



####
##
# Flight range by year and age
#########################################################
####
##
#

### Load near-departure body masses
df.DEP <- cap[cap$Julian_Date > 265 & cap$Residual_Percent_LBM < 107,]

# draw 100 probable fuel loads for juveniles and adults
drws.JUV<-rnorm(100, mean(df.DEP[df.DEP$Age == 2,]$Residual_Percent_LBM),
                sd(df.DEP[df.DEP$Age == 2,]$Residual_Percent_LBM))
#save(drws.JUV,file="drws.JUV.rda")
load("drws.JUV.rda") # load juvenile fuel loads presented in manuscript

drws.ADU<-rnorm(100, mean(df.DEP[df.DEP$Age == 1,]$Residual_Percent_LBM),
                sd(df.DEP[df.DEP$Age == 1,]$Residual_Percent_LBM))
#save(drws.ADU,file="drws.ADU.rda")
load("drws.ADU.rda") # load adult fuel loads presented in manuscript


### Flight model 

# Mean pre-migratory body condition by year and age
df <- group_by(df.PMBC, Age, Year) %>% 
  summarise(
    mean = mean(Body_Condition),
    n = length(Body_Condition),
    se = sd(Body_Condition)/sqrt(length(Body_Condition)))

# Flight data frame
df.FLY<-
  data.frame(Year = c(rep(c(1978,1979,1980,2004,2005,2006,2008,2009,2010),3),
                      rep(c(1978,1979,1980,2008,2009,2010),3),
                      rep(c(1978,1979,1980,2004,2005,2006,2008,2009,2010),2),
                      rep(c(1978,1979,1980,2008,2009,2010),2)),
             Age = c(rep("aJUV",27),rep("bADU",18),rep("aJUV",18),rep("bADU",12)),
             Fuel_load = c(rep(median(drws.JUV),9),rep(quantile(drws.JUV,0.25),9),rep(quantile(drws.JUV,0.75),9),
                           rep(median(drws.ADU),6),rep(quantile(drws.ADU,0.25),6),rep(quantile(drws.ADU,0.75),6),
                           rep(quantile(drws.JUV,0.05),9),rep(quantile(drws.JUV,0.95),9),
                           rep(quantile(drws.ADU,0.05),6),rep(quantile(drws.ADU,0.95),6)),
             FL_type = c(rep("median",9),rep("lqr",9),rep("uqr",9),
                         rep("median",6),rep("lqr",6),rep("uqr",6),
                         rep("l05",9),rep("u95",9),rep("l05",6),rep("u95",6)),
             Annual_offset = c(rep(c((df[1,3]-df[3,3])[1,1],(df[2,3]-df[3,3])[1,1],(df[3,3]-df[3,3])[1,1],
                                     (df[5,3]-df[3,3])[1,1],(df[6,3]-df[3,3])[1,1],(df[7,3]-df[3,3])[1,1],
                                     (df[9,3]-df[3,3])[1,1],(df[10,3]-df[3,3])[1,1],(df[11,3]-df[3,3])[1,1]),3),
                               rep(c((df[12,3]-df[14,3])[1,1],(df[13,3]-df[14,3])[1,1],(df[14,3]-df[14,3])[1,1],
                                     (df[20,3]-df[14,3])[1,1],(df[21,3]-df[14,3])[1,1],(df[22,3]-df[14,3])[1,1]),3),
                               rep(c((df[1,3]-df[3,3])[1,1],(df[2,3]-df[3,3])[1,1],(df[3,3]-df[3,3])[1,1],
                                     (df[5,3]-df[3,3])[1,1],(df[6,3]-df[3,3])[1,1],(df[7,3]-df[3,3])[1,1],
                                     (df[9,3]-df[3,3])[1,1],(df[10,3]-df[3,3])[1,1],(df[11,3]-df[3,3])[1,1]),2),
                               rep(c((df[12,3]-df[14,3])[1,1],(df[13,3]-df[14,3])[1,1],(df[14,3]-df[14,3])[1,1],
                                     (df[20,3]-df[14,3])[1,1],(df[21,3]-df[14,3])[1,1],(df[22,3]-df[14,3])[1,1]),2)),
             DEP_per_lbm = NA,
             #
             Scientific_name = 'Calidris alpina',
             Empty_mass_kg = NA,
             Wing_span = 0.346,
             Fat_mass_kg = NA,
             Order = 2, #1=passerine, 2=non-passerine
             Wing_area = 0.0147, 
             Muscle_mass_kg = NA)

for (i in 1:dim(df.FLY)[1]) {
  df.FLY$DEP_per_lbm[i] <- df.FLY$Fuel_load[i] + df.FLY$Annual_offset[i] # departure %lbm
  df.FLY$Muscle_mass_kg[i] <- 0.0477 * (df.FLY$DEP_per_lbm[i]*0.24/100) # (0.24 = fraction of residual mass attributed to residual muscle)
  df.FLY$Fat_mass_kg[i] <- 0.0477 * (df.FLY$DEP_per_lbm[i]*0.76/100) # (0.76 = fraction of residual mass attributed to residual fat)
  df.FLY$Empty_mass_kg[i] <- 0.0477 + df.FLY$Muscle_mass_kg[i] + df.FLY$Fat_mass_kg[i]
}

# Flight model
flight.range <- migrate(data = df.FLY[,7:13], 
                        settings = list(airDensity = altitude2density(altitude = 717), 
                                        bdc = 0.06, # body drag coefficient 
                                        ipf = 0.9, # induced power factor
                                        speedRatio = 1.98), # true air speed to min power speed ratio
                        method = "csw", # constant specific work
                        speed_control = 1, # constant flight speed
                        min_energy_protein = 0.05)

df.FLY$Range <- flight.range[["range"]]
df.FLY$Start_min_speed <- flight.range[["startMinSpeed"]]
# mean airspeed (must be 21.5 m/s)
mean(df.FLY$Start_min_speed) * 1.98
#########################################################



####
##
# Juvenile flight range by SST
#########################################################
####
##
#

### Averaging lag.sst models w/model weight > 0.05
head(climwin[[5]]$Dataset)

df <- climwin[[5]]$Dataset[1:4,]
SumWeight <- sum(df$ModWeight)
df$ModWeight <- df$ModWeight/SumWeight
ModelBeta <- sum(df$ModelBeta*df$ModWeight)
ModelBetaQ <- sum(df$ModelBetaQ*df$ModWeight)
ModelInt <- sum(df$ModelInt*df$ModWeight)


### Flight model

# Mean 11-24 June SSTs by year (1977-2022)
df.SST <- read.csv("cYKD_SST_11_24Jun_1977_2022.csv")

df.SST.yr <- group_by(df.SST, Year) %>%
  summarise(
    mean = mean(Mean_SST))

# Mean effect of lag.sst on JUV PMBC
df.SST.eff <- data.frame(Mean_SST = c(seq(1.31,10.74,0.01)),
                         Body_Condition = NA)
df.SST.eff$Body_Condition <- ModelInt + (ModelBeta*df.SST.eff$Mean_SST) + (ModelBetaQ*df.SST.eff$Mean_SST^2)
df.SST.eff$BC_offset_1980 <- df.SST.eff$Body_Condition + abs(df.SST.eff$Body_Condition[138])

# Flight data frame
df.FLY.SST<-
  data.frame( Mean_SST = c(rep(seq(1.31,10.74,0.01),3)),
              FL_type = c(rep("median",944),rep("lqr",944),rep("uqr",944)),
              DEP_per_lbm = c((median(drws.JUV) + df.SST.eff$BC_offset_1980),
                              (quantile(drws.JUV,0.25) + df.SST.eff$BC_offset_1980),
                              (quantile(drws.JUV,0.75) + df.SST.eff$BC_offset_1980)),
              #
              Scientific_name = 'Calidris alpina',
              Empty_mass_kg = NA,
              Wing_span = 0.346,
              Fat_mass_kg = NA,
              Order = 2, #1=passerine, 2=non-passerine
              Wing_area = 0.0147,
              Muscle_mass_kg = NA)

for (i in 1:dim(df.FLY.SST)[1]) {
  df.FLY.SST$Muscle_mass_kg[i] <- 0.0477 * (df.FLY.SST$DEP_per_lbm[i]*0.24/100) # (0.24 = fraction of residual mass attributed to residual muscle)
  df.FLY.SST$Fat_mass_kg[i] <- 0.0477 * (df.FLY.SST$DEP_per_lbm[i]*0.76/100) # (0.76 = fraction of residual mass attributed to residual fat)
  df.FLY.SST$Empty_mass_kg[i] <- 0.0477 + df.FLY.SST$Muscle_mass_kg[i] + df.FLY.SST$Fat_mass_kg[i]
}

# Flight model

flight.range.sst <- migrate(data = df.FLY.SST[,4:10], 
                            settings = list(airDensity = altitude2density(altitude = 717), 
                                            bdc = 0.06, # body drag coefficient 
                                            ipf = 0.9, # induced power factor
                                            speedRatio = 1.98), # true air speed to min power speed ratio
                            method = "csw", # constant specific work
                            speed_control = 1, # constant flight speed
                            min_energy_protein = 0.05)

df.FLY.SST$Range <- flight.range.sst[["range"]]

#########################################################



####
##
# Figure 3
#########################################################
####
##
#

# a

# mean body conditions by year
df <- group_by(df.JUV, Year) %>%
  summarise(
    mean = mean(Body_Condition),
    n = length(Body_Condition),
    se = sd(Body_Condition)/sqrt(length(Body_Condition)))

df$SST <- c(2.98,5.30,2.68,7.56,7.51,6.91,4.02,4.03,4.47)

a <- ggplot()+
  geom_hline(yintercept=0, linetype="dashed", color = "grey55") +
  geom_path(data=df.SST.eff[138:626,], aes(x=Mean_SST, y=Body_Condition),color="black", size=1)+
  geom_errorbar(data=df, aes(x=SST, ymin=mean-(se*1.96), ymax=mean+(se*1.96)), width = 0.25) +
  geom_point(data=df, aes(x=SST, y=mean), shape=21, fill="#ee6677", color="black", stroke=0.5, size = 2.5) +
  scale_y_continuous(limits=c(-6,6))+
  labs(x = expression(Avg~SST~year[i-1]~(11-24~Jun*","*degree*C)), 
       y = "Body condition (%lbm)",
       title = expression(paste("(",italic("a"),")")))+
  theme_bw()


# b
quantile(df.SST.yr$mean)

b <- ggplot(df.SST.yr, aes(x=Year, y=mean)) +
  geom_hline(yintercept=4.77, linetype="dashed", color = "grey55") +
  #geom_hline(yintercept=3.39, linetype="dashed", color = "grey55") +
  #geom_hline(yintercept=6.86, linetype="dashed", color = "grey55") +
  geom_point(aes(fill=mean), shape=22, color="black", stroke=0.5, size = 2, show.legend = F) +
  scale_fill_gradient2(midpoint=4.8,low="blue",mid="grey85",high="red", name="degC") +
  labs(x = "Year", 
       y = expression(Avg~SST~(11-24~Jun*","*degree*C)),
       title = expression(paste("(",italic("b"),")")))+
  theme_bw()


# c
df.RNG.SST <- data.frame( Mean_SST = c(seq(1.31,10.74,0.01)),
                          RNG_med = df.FLY.SST$Range[1:944])

df.RNG.poly <- data.frame( Mean_SST = c(seq(1.31,10.74,0.01),seq(10.74,1.31,-0.01),1.31),
                           RNG_iqr = c(df.FLY.SST$Range[945:1888],df.FLY.SST$Range[2832:1889],df.FLY.SST$Range[945]))

c <- ggplot()+
  geom_polygon(data=df.RNG.poly, aes(x=Mean_SST, y=RNG_iqr), fill="grey55", alpha=0.3)+
  geom_hline(yintercept=3205, linetype="dotted", color = "black", size=1) +  
  geom_path(data=df.RNG.SST, aes(x=Mean_SST, y=RNG_med), color="#ee6677", size=1)+
  annotate("text", x = 5, y = 1750, label = "Minimum distance to\nprimary wintering grounds", colour = "black", size = 4) +
  geom_line(aes(x=c(4.5,5),y=c(2250,3050)), size=0.5, color="grey55")+
  labs(x = expression(Avg~SST~year[i-1]~(11-24~Jun*","*degree*C)), 
       y = "Flight range (km)",
       title = expression(paste("(",italic("c"),")")))+
  theme_bw()


plot_grid(a,b,c,ncol=1,nrow=3)

#ggsave(filename = "Fig3.jpeg", width=3.5, height=9.54, units="in", dpi=300)

#########################################################



####
##
# Figure 4
#########################################################

df.RNG <- data.frame( Year = as.factor(c(as.character(df.FLY$Year[1:18]),rep("2003",2),rep("2007",2))),
                      Age = as.factor(c(rep("aJUV",9),rep("bADU",9),rep(c("aJUV","bADU"),2))),
                      RNG_med = c(df.FLY$Range[1:9],df.FLY$Range[28:30],rep(0,3),df.FLY$Range[31:33],rep(0,4)),
                      RNG_lqr = c(df.FLY$Range[10:18],df.FLY$Range[34:36],rep(0,3),df.FLY$Range[37:39],rep(0,4)),
                      RNG_uqr = c(df.FLY$Range[19:27],df.FLY$Range[40:42],rep(0,3),df.FLY$Range[43:45],rep(0,4)),
                      RNG_l05 = c(df.FLY$Range[46:54],df.FLY$Range[64:66],rep(0,3),df.FLY$Range[67:69],rep(0,4)),
                      RNG_u95 = c(df.FLY$Range[55:63],df.FLY$Range[70:72],rep(0,3),df.FLY$Range[73:75],rep(0,4)))


ggplot(df.RNG, aes(x=Year, y=RNG_med, fill=Age)) +
  geom_hline(yintercept=3205, linetype="dotted", color = "black", size=1) +
  #geom_errorbar(aes(ymin=RNG_l05, ymax=RNG_u95), width = 0.4, position=position_dodge(width=0.85)) +
  geom_point(shape=21, stroke=0.5, size = 2, position=position_dodge(width=0.80)) +
  geom_boxplot(aes(ymin = RNG_l05, lower = RNG_lqr, middle = RNG_med, upper = RNG_uqr, ymax = RNG_u95),
               stat = "identity", position=position_dodge(width=0.80), show.legend = FALSE) +
  scale_x_discrete(breaks=c(1978,1979,1980,2003,2004,2005,2006,2007,2008,2009,2010),
                   labels=c("'78","'79","'80","","'04","'05","'06","","'08","'09","'10"))+
  scale_y_continuous(limits = c(1800,14000), breaks=c(2500,5000,7500,10000,12500)) +
  scale_fill_manual(labels=c("JUV", "ADU"),values=c("#ee6677", "#4477aa"))+
  labs(x = "Year", 
       y = "Flight range (km)",
       title = expression(paste("")),
       fill = NULL)+
  theme_bw() +
  theme(plot.margin=unit(c(18,5.5,5.5,5.5), 'pt'),
        legend.direction="horizontal",legend.position=c(0.2,1.085))


#ggsave(filename = "Fig4.jpeg", width=3.5, height=3.18, units="in", dpi=300)

#########################################################



####
##
# The end
